/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.isobus.model.BinaryWriter;
import nl.cloudfarming.client.isobus.model.DDI;
import nl.cloudfarming.client.isobus.model.GridTypeEnum;
import nl.cloudfarming.client.task.grid.TreatmentZoneGrid;
import org.openide.filesystems.FileAlreadyLockedException;
import org.openide.filesystems.FileObject;

/**
 * Writer class for grid binary files Fires property change event
 * GridWriter.PROP_FINISHED when writing is finished
 *
 * @author Merijn Zengers
 */
public class GridWriter {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.isobus.model");

    /**
     * Writes a grid file to the supplied destination FileObject Registers a
     * FileListener on the file which listens to file change When the file is
     * changed it fires a propertchangeEvent PROP_FINISHED If this property is
     * not filled an assertion exception is thrown
     *
     * @param destination the destination folder this grid file should be
     * written in
     * @param gridType the type to write 
     * @param TreatmentZoneGrid the TreatmentZoneGrid containing the treatment
     * zones mapped to unique ids
     */
    public void write(FileObject destination, GridTypeEnum gridType, TreatmentZoneGrid treatmentZoneGrid, DDI ddi, double multiplier) {
        // Generate actual grid
        try {
            try (BinaryWriter binaryWriter = new BinaryWriter(destination.getOutputStream())) {
                for (int row = treatmentZoneGrid.getNumberOfRows() - 1; row >= 0; row--) {
                    for (TreatmentZoneGrid.TreatmentZoneData data : treatmentZoneGrid.getRow(row)) {
                        if (GridTypeEnum.TYPE_1.equals(gridType)) {
                            binaryWriter.write(GridFieldEnum.TREATMENT_ZONE_CODE_TYPE, data.getCode());
                        } else if(GridTypeEnum.TYPE_2.equals(gridType)){
                            binaryWriter.write(GridFieldEnum.TREATMENT_ZONE_VALUE_TYPE, ddi.toExportValue(data.getValue() * multiplier));
                        }
                    }
                }
            }
        } catch (FileAlreadyLockedException ex) {
            LOGGER.log(Level.SEVERE, "Failed writing gridfile. (File already locked) with exception {0}", ex.getMessage());
        } catch (IOException ex) {
            LOGGER.log(Level.SEVERE, "Failed writing gridfile. (IOException) with exception", ex.getMessage());
        }
    }
}
