/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.isobus.type;

/**
 * storage for a grid of raw process data values.
 * 
 * @author johan
 */
public class IsobusValueGrid {
    private final int[][] grid; // match type of ProcessDataVariable.ProcessDataValue
    private final int numberOfColumns;
    private final int numberOfRows;
    
    public IsobusValueGrid(int numberOfRows, int numberOfColumn){
        grid = new int[numberOfRows][numberOfColumn];
        this.numberOfRows = numberOfRows;
        this.numberOfColumns = numberOfColumn;
    }
    
    public void insert(int row, int column, int value) {
        grid[row][column] = value;
    }
    
    public int getValue(int row, int column) {
        return grid[row][column];
    }

    public int[] getValues() {
        // merge grid into single array for use with raster:
        int[] allValues = new int[getSize()];
        
        for (int i = 0, offset = 0; i < numberOfRows; i++, offset += numberOfColumns) {
            System.arraycopy(grid[i], 0, allValues, offset, numberOfColumns);
        }
        return allValues;
    }

    public int getNumberOfColumns() {
        return numberOfColumns;
    }

    public int getNumberOfRows() {
        return numberOfRows;
    }
    
    public int getSize(){
        return numberOfColumns * numberOfRows;
    }
}
